@@ -20,7 +20,6 @@
 
 #include <array>
 
-#include "katemodelinecompletion.h"
 #include "katetextfolding.h"
 #include "katetextrange.h"
 
@@ -80,7 +79,6 @@ class KTEXTEDITOR_EXPORT ViewPrivate final : public KTextEditor::View
     friend class KTextEditor::View;
     friend class ::KateViewInternal;
     friend class ::KateIconBorder;
-    friend class ::KateTextPreview;
     friend MulticursorTest;
 
 public:
@@ -366,7 +364,10 @@ public Q_SLOTS:
 
 public:
     KateCompletionWidget *completionWidget() const;
-    mutable KateCompletionWidget *m_completionWidget;
+
+    // we re-parent this, use a QPointer to be sure we know if that is still alive
+    mutable QPointer<KateCompletionWidget> m_completionWidget;
+
     void sendCompletionExecuted(const KTextEditor::Cursor position, KTextEditor::CodeCompletionModel *model, const QModelIndex &index);
     void sendCompletionAborted();
 
@@ -434,8 +435,6 @@ public:
     bool blockSelection() const override;
     KTextEditor::Range selectionRange() const override;
 
-    static void blockFix(KTextEditor::Range &range);
-
     //
     // Arbitrary Syntax HL + Action extensions
     //
@@ -843,6 +842,9 @@ public:
     // should the cursor be painted during rendering?
     bool isCursorVisible() const;
 
+    // should the bracket match be highlighted during rendering?
+    bool isBracketMatchHighlightActive() const;
+
 private Q_SLOTS:
     void slotDocumentReloaded();
     void slotDocumentAboutToReload();
